# https://github.com/bbakersmith/jekyll-pages-directory / commit: 1abb41fbc9a064b7498f52a797cda53505525883
# Based off the latest commit, with additional tweaks to allow _pages within collections_dir
module Jekyll
	class PagesDirGenerator < Generator
	  def generate(site)
		pages_dir = site.config['pages'] || (site.config['collections_dir'] ? site.config['collections_dir'] + '/_pages' : nil) || './_pages'
		all_raw_paths = Dir["#{site.source}/#{pages_dir}/**/*"]
		all_raw_paths.each do |f|

		  if File.file?(f)
			filename = f.match(/[^\/]*$/)[0]
			clean_filepath = f.gsub(/^#{site.source}\/#{pages_dir}\//, '')
			clean_dir = extract_directory(clean_filepath)

			site.pages << PagesDirPage.new(site,
										   site.source,
										   clean_dir,
										   filename,
										   pages_dir)

		  end
		end
	  end

	  def extract_directory(filepath)
		dir_match = filepath.match(/(.*\/)[^\/]*$/)
		if dir_match
		  return dir_match[1]
		else
		  return ''
		end
	  end
	end

	class PagesDirPage < Page

	  def initialize(site, base, dir, name, pagesdir)
		@site = site
		@base = base
		@dir = dir
		@name = name

		process(name)
		read_yaml(File.join(base, pagesdir, dir), name)

		data.default_proc = proc do |hash, key|
		  site.frontmatter_defaults.find(File.join(dir, name), type, key)
		end

		Jekyll::Hooks.trigger :pages, :post_init, self
	  end
	end
  end
